@@ -114,8 +114,8 @@ def main() -> None:
     if exit_code != 0:
         status = status_flags.package_build_failed
     else:
-        # NOTE: currently we are looking for rpm results only
-        # on support of building other package formats the
+        # NOTE: currently we are looking for rpm and deb results
+        # only on support of building other package formats the
         # following code needs to be updated
         status = status_flags.package_build_succeeded
         find_call = Command.run(
@@ -123,7 +123,7 @@ def main() -> None:
                 'find', os.path.join(
                     args['--root'], Defaults.get_runner_results_root()
                 ),
-                '-name', '*.rpm'
+                '-name', '*.rpm', '-o', '-name', '*.deb'
             ]
         )
         if find_call.output:
